//
// Copyright (c) Graphcore Ltd. All rights reserved.
//
// Automatically generated file.
//
// Generated by: GenerateAttributes.py
// Input file: attributes.json
// Attribute definitions.

#ifndef _IPUATTRIBUTES_H_
#define _IPUATTRIBUTES_H_

#include <string>

namespace IPUAttributes {

/** IPU devices have attributes associated with them.
    Note not all attributes will be set for a given device. Some are set for
    specific device types only, where this is the case the relevant device type
    is indicated in brackets, for example (IPUoF). Attributes relating to the
    process using an IPU are only set when the IPU is in use.
*/

enum class AttributeId {
  /// Unique identifier of a single-IPU or multi-IPU device.
  DeviceId = 0,
  /// Average temperature in degrees Celsius as read by the sensors on the board.
  AverageBoardTemp = 1,
  /// Average temperature in degrees Celsius as read by IPU sensors.
  AverageDieTemp = 2,
  /// IPU number on board (0-1 for PCIe cards, 0-3 for IPU-Machines).
  BoardIpuIndex = 3,
  /// The IPU board type 'family', for example C600 or M2000. Note: M2000 includes IPU-M2000 and Bow-2000.
  BoardType = 4,
  /// Current clock frequency.
  ClockFrequency = 5,
  /// (IPUoF) Config domain, used to identify which partition an IPU belongs to.
  ConfigDomain = 6,
  /// PCIe driver version, specified as a <major.minor.patch> triple.
  DriverVersion = 7,
  /// ICU firmware major version.
  FirmwareMajorVersion = 8,
  /// ICU firmware minor version.
  FirmwareMinorVersion = 9,
  /// ICU firmware patch version.
  FirmwarePatchVersion = 10,
  /// (IPUoF) IPU-Gateway software version, specified as a <major.minor.patch> triple.
  GatewaySoftwareVersion = 11,
  /// (IPUoF) Graphcore Compile Domain ID.
  GcdId = 12,
  /// Legacy. Replaced by RemoteBuffersSupported.
  GraphStreaming = 13,
  /// Total remote-buffer memory available.
  HexoattTotalSize = 14,
  /// Total remote buffer-memory in use by the IPU.
  HexoattActiveSize = 15,
  /// Total host exchange memory available.
  HexoptTotalSize = 16,
  /// Total host exchange memory in use by the IPU.
  HexoptActiveSize = 17,
  /// IPU hardware architecture version.
  IpuArchitecture = 18,
  /// (IPUoF) IP address of IPU-Gateway.
  IpuofHost = 19,
  /// (IPUoF) Fabric server version.
  IpuofServerVersion = 20,
  /// [deprecated] Percentage time spent waiting for one or more IPU syncs in the last second.
  IpuSyncUtilisation = 21,
  /// Percentage of time spent waiting for one or more IPU syncs, measured in the last second.
  IpuUtilisation = 22,
  /// Percentage of time spent waiting for one or more IPU syncs since the HSPs were set up.
  IpuUtilisationSession = 23,
  /// IPU Link correctable error count.
  LinkCorrectableErrorCount = 24,
  /// (PCIe) PCIe link speed available.
  LinkSpeed = 25,
  /// (PCIe) Number of PCIe lanes available.
  LinkWidth = 26,
  /// Maximum active code size (bytes).
  MaxActiveCodeSize = 27,
  /// Maximum active data size (bytes).
  MaxActiveDataSize = 28,
  /// Maximum active stack size (bytes).
  MaxActiveStackSize = 29,
  /// Multi-IPU device the IPU belongs to.
  MultiIpuDeviceId = 30,
  /// Method used to discover multi-IPU groups.
  MultiIpuDiscoveryMethod = 31,
  /// NUMA node the IPU is on.
  NumaNode = 32,
  /// (IPUoF) Number of IPU-Link segments.
  NumIpuLinkSegments = 33,
  /// (IPUoF) Number of replicas in the partition.
  NumReplicas = 34,
  /// (Simulator) Number of tiles per IPU.
  NumTiles = 35,
  /// Set to 1 if the parity of the IPU's tile memory is initialised.
  ParityInitialised = 36,
  /// (IPUoF) partition ID.
  PartitionId = 37,
  /// (IPUoF) sync configuration type, for example 'c2-compatible'.
  PartitionSyncType = 38,
  /// PCIe device identifier.
  PciId = 39,
  /// PCIe physical slot.
  PhysicalSlot = 40,
  /// The start time of the process currently using the IPU.
  ProcessStartTime = 41,
  /// (IPUoF) Set to 1 if the IPU is part of a reconfigurable partition.
  ReconfigurablePartition = 42,
  /// Set to 1 if remote buffers are supported.
  RemoteBuffersSupported = 43,
  /// (IPUoF) Device ID within routing configuration.
  RoutingId = 44,
  /// (IPUoF) Link configuration for partition, for example, 'DNC'.
  RoutingType = 45,
  /// (RPC) Underlying ID of device being debugged.
  RpcServerMasterId = 46,
  /// (RPC) Debug server host address.
  RpcServerHost = 47,
  /// (RPC) Debug server port number.
  RpcServerPort = 48,
  /// (RPC) Debug server version.
  RpcServerVersion = 49,
  /// Serial number of the board.
  SerialNumber = 50,
  /// File number representing device in sysfs.
  SysfsFileId = 51,
  /// Total current power consumption as read by board level sensors.  Not used on IPU-Machines
  TotalBoardPower = 52,
  /// (USB) USB device ID.
  UsbId = 53,
  /// (USB) USB device product ID.
  UsbProductId = 54,
  /// (USB) USB device location.
  UsbSlot = 55,
  /// (USB) USB device vendor ID.
  UsbVendorId = 56,
  /// The name of the process using the device.
  UserExecutable = 57,
  /// The username of the user using the device.
  UserName = 58,
  /// The process IDs of the process using the device.
  UserProcessId = 59,
  /// (IPUoF) GW-Link routing type.
  GatewayRoutingType = 60,
  /// (IPUoF) Identifier of IPU-Link segment.
  IpuLinkSegmentId = 61,
  /// Number of Graph Compile Domains.
  NumGcds = 62,
  /// ICU Firmware version, specified as a <major.minor.patch> triple.  In development builds, this will be suffixed with branch and build information.
  FirmwareVersion = 63,
  /// (IPUoF) Set if error occurred while attempting to communicate with the IPUoF server (a 'connection' error), or if the IPUoF server was unable to use the device (a 'device' error)
  IpuofServerError = 64,
  /// (PCIe) Host Link correctable error count.
  HostLinkCorrectableErrorCount = 65,
  /// (IPUoF) IP address of the headnode where the application using this IPU is running.
  ApplicationHost = 66,
  /// Error state of the IPU. Set to 'ipu memory failure' if the tile parity error thresholds have been exceeded.
  IpuErrorState = 67,
  /// Threshold for number of parity errors to promote to a unrecoverable error.
  ParityErrorCountThreshold = 68,
  /// Threshold in seconds at which 'num parity errors' are promoted to an uncorrectable error.
  ParityErrorThresholdInterval = 69,
  /// (IPUoF) IPU-M software version.
  IpumSoftwareVersion = 70,
  /// Power consumption of a single IPU.  Only available on IPU-Machines
  IpuPower = 71,
  /// IPU Link correctable error count since device was last reset.
  LinkCorrectableErrorCountSession = 72,
  /// (PCIe) Host-Link correctable error count since device was last reset.
  HostLinkCorrectableErrorCountSession = 73,
  /// IPU board model name.  This will be identical to BoardType if this product only has a single variant.
  BoardVariant = 74,
  /// Gateway write combining status.
  GatewayWriteCombining = 75,
  /// Set to 1 if the secondary interface is supported.
  SecondaryPcieInterfaceSupported = 76,
  /// ICU bootloader version, specified as a <major.minor.patch> triple. In development builds, this will be suffixed with branch and build information.
  ICUBootloaderVersion = 77,
  UnknownAttribute = 0xffff
};

inline const char *GetLabelFromAttributeId(AttributeId attr) {
  switch (attr) {
  case AttributeId::DeviceId:
    return "id";
  case AttributeId::AverageBoardTemp:
    return "average board temp";
  case AttributeId::AverageDieTemp:
    return "average die temp";
  case AttributeId::BoardIpuIndex:
    return "board ipu index";
  case AttributeId::BoardType:
    return "board type";
  case AttributeId::ClockFrequency:
    return "clock";
  case AttributeId::ConfigDomain:
    return "config domain";
  case AttributeId::DriverVersion:
    return "driver version";
  case AttributeId::FirmwareMajorVersion:
    return "firmware major version";
  case AttributeId::FirmwareMinorVersion:
    return "firmware minor version";
  case AttributeId::FirmwarePatchVersion:
    return "firmware patch version";
  case AttributeId::GatewaySoftwareVersion:
    return "gateway software version";
  case AttributeId::GcdId:
    return "gcd id";
  case AttributeId::GraphStreaming:
    return "graph streaming";
  case AttributeId::HexoattTotalSize:
    return "hexoatt total size (bytes)";
  case AttributeId::HexoattActiveSize:
    return "hexoatt active size (bytes)";
  case AttributeId::HexoptTotalSize:
    return "hexopt total size (bytes)";
  case AttributeId::HexoptActiveSize:
    return "hexopt active size (bytes)";
  case AttributeId::IpuArchitecture:
    return "ipu architecture";
  case AttributeId::IpuofHost:
    return "ipuof host";
  case AttributeId::IpuofServerVersion:
    return "ipuof server version";
  case AttributeId::IpuUtilisation:
    return "ipu utilisation";
  case AttributeId::IpuUtilisationSession:
    return "ipu utilisation (session)";
  case AttributeId::LinkCorrectableErrorCount:
    return "link correctable error count";
  case AttributeId::LinkSpeed:
    return "link speed";
  case AttributeId::LinkWidth:
    return "link width";
  case AttributeId::MaxActiveCodeSize:
    return "max active code size (bytes)";
  case AttributeId::MaxActiveDataSize:
    return "max active data size (bytes)";
  case AttributeId::MaxActiveStackSize:
    return "max active stack size (bytes)";
  case AttributeId::MultiIpuDeviceId:
    return "multi-ipu device id";
  case AttributeId::MultiIpuDiscoveryMethod:
    return "multi-ipu discovery method";
  case AttributeId::NumaNode:
    return "numa node";
  case AttributeId::NumIpuLinkSegments:
    return "number of ipu-link segments";
  case AttributeId::NumReplicas:
    return "number of replicas";
  case AttributeId::NumTiles:
    return "number of tiles";
  case AttributeId::ParityInitialised:
    return "parity initialised";
  case AttributeId::PartitionId:
    return "ipuof partition id";
  case AttributeId::PartitionSyncType:
    return "partition sync type";
  case AttributeId::PciId:
    return "pci id";
  case AttributeId::PhysicalSlot:
    return "pcie physical slot";
  case AttributeId::ProcessStartTime:
    return "process start time";
  case AttributeId::ReconfigurablePartition:
    return "reconfigurable partition";
  case AttributeId::RemoteBuffersSupported:
    return "remote buffers supported";
  case AttributeId::RoutingId:
    return "ipuof routing id";
  case AttributeId::RoutingType:
    return "ipuof routing type";
  case AttributeId::RpcServerMasterId:
    return "rpc server master device id";
  case AttributeId::RpcServerHost:
    return "rpc server host";
  case AttributeId::RpcServerPort:
    return "rpc server port";
  case AttributeId::RpcServerVersion:
    return "rpc server version";
  case AttributeId::SerialNumber:
    return "board serial number";
  case AttributeId::SysfsFileId:
    return "sysfs file id";
  case AttributeId::TotalBoardPower:
    return "total board power";
  case AttributeId::UsbId:
    return "usb device id";
  case AttributeId::UsbProductId:
    return "usb product id";
  case AttributeId::UsbSlot:
    return "usb slot";
  case AttributeId::UsbVendorId:
    return "usb vendor id";
  case AttributeId::UserExecutable:
    return "user executable";
  case AttributeId::UserName:
    return "user name";
  case AttributeId::UserProcessId:
    return "user process id";
  case AttributeId::GatewayRoutingType:
    return "gateway routing type";
  case AttributeId::IpuLinkSegmentId:
    return "ipu link segment id";
  case AttributeId::NumGcds:
    return "number of gcds";
  case AttributeId::FirmwareVersion:
    return "firmware version";
  case AttributeId::IpuofServerError:
    return "ipuof server error";
  case AttributeId::HostLinkCorrectableErrorCount:
    return "host link correctable error count";
  case AttributeId::ApplicationHost:
    return "application host";
  case AttributeId::IpuErrorState:
    return "ipu error state";
  case AttributeId::ParityErrorCountThreshold:
    return "parity error count threshold";
  case AttributeId::ParityErrorThresholdInterval:
    return "parity error threshold interval";
  case AttributeId::IpumSoftwareVersion:
    return "ipum software version";
  case AttributeId::IpuPower:
    return "ipu power";
  case AttributeId::LinkCorrectableErrorCountSession:
    return "link correctable error count (session)";
  case AttributeId::HostLinkCorrectableErrorCountSession:
    return "host link correctable error count (session)";
  case AttributeId::BoardVariant:
    return "board variant";
  case AttributeId::GatewayWriteCombining:
    return "gateway write combining";
  case AttributeId::SecondaryPcieInterfaceSupported:
    return "secondary pcie interface supported";
  case AttributeId::ICUBootloaderVersion:
    return "icu bootloader version";
  default:
    return nullptr;
  }
}

inline const char *GetLegacyLabelFromAttributeId(AttributeId attr) {
  switch (attr) {
  case AttributeId::DeviceId:
    return "id";
  case AttributeId::AverageBoardTemp:
    return "average board temp";
  case AttributeId::AverageDieTemp:
    return "average die temp";
  case AttributeId::BoardIpuIndex:
    return "IPU";
  case AttributeId::BoardType:
    return "type";
  case AttributeId::ClockFrequency:
    return "clock";
  case AttributeId::ConfigDomain:
    return "Config Domain";
  case AttributeId::DriverVersion:
    return "Driver version";
  case AttributeId::FirmwareMajorVersion:
    return "Firmware Major Version";
  case AttributeId::FirmwareMinorVersion:
    return "Firmware Minor Version";
  case AttributeId::FirmwarePatchVersion:
    return "Firmware Patch Version";
  case AttributeId::GatewaySoftwareVersion:
    return "gateway software version";
  case AttributeId::GcdId:
    return "GCD Id";
  case AttributeId::GraphStreaming:
    return "graph streaming";
  case AttributeId::HexoattTotalSize:
    return "hexoatt total size";
  case AttributeId::HexoattActiveSize:
    return "hexoatt used size";
  case AttributeId::HexoptTotalSize:
    return "hexopt total size";
  case AttributeId::HexoptActiveSize:
    return "hexopt used size";
  case AttributeId::IpuArchitecture:
    return "IPU version";
  case AttributeId::IpuofHost:
    return "Location";
  case AttributeId::IpuofServerVersion:
    return "Server version";
  case AttributeId::IpuSyncUtilisation:
    return "IPU sync utilisation";
  case AttributeId::IpuUtilisation:
    return "IPU utilisation";
  case AttributeId::IpuUtilisationSession:
    return "IPU utilisation session";
  case AttributeId::LinkCorrectableErrorCount:
    return "link correctable error count";
  case AttributeId::LinkSpeed:
    return "link speed";
  case AttributeId::LinkWidth:
    return "link width";
  case AttributeId::MaxActiveCodeSize:
    return "max running code size";
  case AttributeId::MaxActiveDataSize:
    return "max running data size";
  case AttributeId::MaxActiveStackSize:
    return "max running stack size";
  case AttributeId::MultiIpuDeviceId:
    return "MultiIPU";
  case AttributeId::MultiIpuDiscoveryMethod:
    return "MultiIPU discovery";
  case AttributeId::NumaNode:
    return "numa node";
  case AttributeId::NumIpuLinkSegments:
    return "Num IPU Link Segments";
  case AttributeId::NumReplicas:
    return "Num Replicas";
  case AttributeId::NumTiles:
    return "Num tiles";
  case AttributeId::ParityInitialised:
    return "parity initialised";
  case AttributeId::PartitionId:
    return "Partition ID";
  case AttributeId::PartitionSyncType:
    return "Sync Type";
  case AttributeId::PciId:
    return "PCI Id";
  case AttributeId::PhysicalSlot:
    return "physical slot";
  case AttributeId::ProcessStartTime:
    return "process start time";
  case AttributeId::ReconfigurablePartition:
    return "Fabric Reconfigurable";
  case AttributeId::RemoteBuffersSupported:
    return "remote buffers";
  case AttributeId::RoutingId:
    return "Routing Id";
  case AttributeId::RoutingType:
    return "Routing Type";
  case AttributeId::RpcServerMasterId:
    return "Master Id";
  case AttributeId::RpcServerHost:
    return "rpc server host";
  case AttributeId::RpcServerPort:
    return "Port";
  case AttributeId::RpcServerVersion:
    return "rpc server version";
  case AttributeId::SerialNumber:
    return "serial number";
  case AttributeId::SysfsFileId:
    return "sysfs file id";
  case AttributeId::TotalBoardPower:
    return "total board power";
  case AttributeId::UsbId:
    return "USB ID";
  case AttributeId::UsbProductId:
    return "PID";
  case AttributeId::UsbSlot:
    return "USB Slot";
  case AttributeId::UsbVendorId:
    return "VID";
  case AttributeId::UserExecutable:
    return "user executable";
  case AttributeId::UserName:
    return "user name";
  case AttributeId::UserProcessId:
    return "user process id";
  case AttributeId::GatewayRoutingType:
    return "Gateway Routing Type";
  case AttributeId::IpuLinkSegmentId:
    return "IPU Link Segment ID";
  case AttributeId::NumGcds:
    return "Num GCDs";
  case AttributeId::FirmwareVersion:
    return "firmware version";
  case AttributeId::IpuofServerError:
    return "ipuof server error";
  case AttributeId::HostLinkCorrectableErrorCount:
    return "host link correctable error count";
  case AttributeId::ApplicationHost:
    return "application host";
  case AttributeId::IpuErrorState:
    return "ipu error state";
  case AttributeId::ParityErrorCountThreshold:
    return "parity error count threshold";
  case AttributeId::ParityErrorThresholdInterval:
    return "parity error threshold interval";
  case AttributeId::IpumSoftwareVersion:
    return "ipum software version";
  case AttributeId::IpuPower:
    return "ipu power";
  case AttributeId::LinkCorrectableErrorCountSession:
    return "link correctable error count (session)";
  case AttributeId::HostLinkCorrectableErrorCountSession:
    return "host link correctable error count (session)";
  case AttributeId::BoardVariant:
    return "board variant";
  case AttributeId::GatewayWriteCombining:
    return "gateway write combining";
  case AttributeId::SecondaryPcieInterfaceSupported:
    return "secondary pcie interface supported";
  case AttributeId::ICUBootloaderVersion:
    return "icu bootloader version";
  default:
    return nullptr;
  }
}

IPUAttributes::AttributeId GetAttributeIdFromLabel(const std::string& label);

} // namespace IPUAttributes

#endif // _IPUATTRIBUTES_H_

