/*
 * Copyright (c) 2021 Graphcore Ltd, All rights reserved.
 */

// gcipuinfo examples:
// Display a list of applications currently using IPUs (if any).
// This is a simple demonstration of the getNamedAttributeForAll()
// function.

#include <iostream>
#include <string.h>

#include "graphcore_target_access/gcipuinfo/IPUAttributeLabels.h"
#include "graphcore_target_access/gcipuinfo/gcipuinfo.h"

int main(int argc, char *argv[]) {

  DeviceDiscoveryMode discoveryMode = DiscoverActivePartitionIPUs;
  if (argc > 1) {
    if (strcmp(argv[1], "--all-partitions") == 0) {
      discoveryMode = DiscoverAllPartitionIPUs;
    } else {
      std::cerr << "Error, unrecognised option.\n";
      std::cerr << "Specify --all-partitions to show IPUs in all partitions\n";
      std::exit(1);
    }
  }
  gcipuinfo inventory(discoveryMode);

  auto apps =
      inventory.getNamedAttributeForAll(IPUAttributeLabels::UserExecutable);

  std::cout << "Graphcore active apps: " << apps.size() << "\n";
  unsigned index = 0;
  for (auto &exeName : apps) {

    if (exeName.size()) {
      std::cout << " o application #" << index++ << ": [" << exeName << "]\n";
    }
    index++;
  }

  return 0;
}
