/*
 * Copyright (c) 2021 Graphcore Ltd, All rights reserved.
 */

// gcipuinfo examples:
// Loop forever, displaying a subset of attributes associated with
// devices that are currently in use.
// This demonstrates the getDevices() function

#include <iostream>
#include <string.h>
#include <unistd.h>

#include "graphcore_target_access/gcipuinfo/IPUAttributeLabels.h"
#include "graphcore_target_access/gcipuinfo/gcipuinfo.h"

void printAttribute(const std::map<std::string, std::string> &map,
                    const std::string &key) {
  if (map.count(key) == 0)
    return;
  std::cout << "  " << key << " : " << map.at(key) << "\n";
}

int main(int argc, char *argv[]) {

  DeviceDiscoveryMode discoveryMode = DiscoverActivePartitionIPUs;
  if (argc > 1) {
    if (strcmp(argv[1], "--all-partitions") == 0) {
      discoveryMode = DiscoverAllPartitionIPUs;
    } else {
      std::cerr << "Error, unrecognised option.\n";
      std::cerr << "Specify --all-partitions to show IPUs in all partitions\n";
      std::exit(1);
    }
  }
  gcipuinfo inventory(discoveryMode);

  std::cout << "Devices:\n";

  unsigned count = 0;
  while (1) {
    std::cout << "*** Iteration " << count++ << " ***\n\n";

    inventory.updateData(); // Refresh the device attribute values

    auto deviceMaps = inventory.getDevices();
    for (auto deviceMap : deviceMaps) {
      std::cout << "Device " << deviceMap.at(IPUAttributeLabels::DeviceId)
                << "\n";

      // Only devices that are in use will have a process id associated with
      // them
      if (deviceMap.count(IPUAttributeLabels::UserProcessId)) {
        printAttribute(deviceMap, IPUAttributeLabels::UserProcessId);
        printAttribute(deviceMap, IPUAttributeLabels::UserExecutable);
        printAttribute(deviceMap, IPUAttributeLabels::UserName);
      } else {
        std::cout << "  (device not in use by any known process)\n";
      }
      printAttribute(deviceMap, IPUAttributeLabels::BoardIpuIndex);
      printAttribute(deviceMap, IPUAttributeLabels::SerialNumber);
      printAttribute(deviceMap, IPUAttributeLabels::ClockFrequency);
      printAttribute(deviceMap, IPUAttributeLabels::TotalBoardPower);
      printAttribute(deviceMap, IPUAttributeLabels::AverageBoardTemp);
      printAttribute(deviceMap, IPUAttributeLabels::IpuUtilisation);
      printAttribute(deviceMap, IPUAttributeLabels::MaxActiveCodeSize);
      printAttribute(deviceMap, IPUAttributeLabels::MaxActiveDataSize);
      printAttribute(deviceMap, IPUAttributeLabels::MaxActiveStackSize);
      std::cout << "\n";
    }
    sleep(1);
  }

  return 0;
}
