/*
 * Copyright (c) 2021 Graphcore Ltd, All rights reserved.
 */

// gcipuinfo examples:
// Display health check results forever on all currently configured devices.

#include <chrono>
#include <iostream>
#include <string.h>
#include <thread>

#include "graphcore_target_access/gcipuinfo/gcipuinfo.h"
#include <nlohmann/json.hpp>

using json = nlohmann::json;

int main(int argc, char *argv[]) {

  DeviceDiscoveryMode discoveryMode = DiscoverActivePartitionIPUs;
  if (argc > 1) {
    if (strcmp(argv[1], "--all-partitions") == 0) {
      discoveryMode = DiscoverAllPartitionIPUs;
    } else {
      std::cerr << "Error, unrecognised option.\n";
      std::cerr << "Specify --all-partitions to show IPUs in all partitions\n";
      std::exit(1);
    }
  }
  gcipuinfo inventory(discoveryMode);

  unsigned count = 0;
  unsigned numIPUs = inventory.getDevices().size();
  while (true) {
    std::cout << "*** Iteration " << count++ << " ***\n\n";
    std::cout << "Checking " << numIPUs << " devices:\n";
    // Set 100ms timeout on response from each IPU.  Don't check active IPUs.
    std::string devicesHealth = inventory.checkHealthOfDevices(100, false);
    std::cout << "Raw JSON: " << devicesHealth << "\n";
    json j = json::parse(devicesHealth);
    if (j.contains("hosts")) {
      std::cout << "Parsed:\n";
      auto hosts = j["hosts"];
      for (auto host : hosts.items()) {
        std::cout << "  host: " << host.key() << "\n";
        for (auto device : host.value().items()) {
          std::cout << "    device id: " << device.value()["id"]
                    << ", partition: " << device.value()["partition"]
                    << ", error: " << device.value()["error"] << "\n";
        }
      }
    } else if (j.contains("error")) {
      std::cout << "Parsed:\n";
      std::cout << "    error: " << j["error"]
                << ", description: " << j["description"] << "\n";
    } else {
      std::cout << "No errors\n";
    }
    std::cout << "\n";
    std::this_thread::sleep_for(std::chrono::milliseconds(10));
  }

  return 0;
}
