//
// Copyright (c) 2021 Graphcore Ltd, All rights reserved.
//

// gcipuinfo examples:
// Check each of the application event record paths specified
// as command line arguments.  If an entry is found, display it.
// Also collect a list of all IPU-Machine hosts named in
// at least one event.

package main

import (
	"fmt"
	"os"
	"gcipuinfo"
	"encoding/json"
)

func main() {
	inventory := gcipuinfo.NewGcipuinfo()

	if len(os.Args) < 2 {
		panic("Error, requires at least one argument")
	}

	hostsNamedInErrors := map[string]bool{}

	for i := 1; i < len(os.Args); i++ {
		path := os.Args[i]
		fmt.Println("== Checking application event record: ", path)
		eventRecordJSON := inventory.GetLastAppEventRecordAsJSON(gcipuinfo.EventSevNone, path)
		var eventRecord map[string]interface{}
		json.Unmarshal([]byte(eventRecordJSON), &eventRecord)
		if len(eventRecord) == 0 {
			fmt.Printf("No event record entry found.\n")
		} else {
			fmt.Println(eventRecordJSON)

			// If the event has named specific IPUs
			// record their associated machine names
			foundSpecificHosts := false
			if _, ok := eventRecord[gcipuinfo.KeySpecificIPUHosts]; ok {
				hosts := eventRecord[gcipuinfo.KeySpecificIPUHosts].([]interface{})
				foundSpecificHosts = len(hosts) > 0
				for _, host := range hosts {
					hostsNamedInErrors[fmt.Sprint(host)] = true
				}
			}
			if !foundSpecificHosts {
				// if no specific IPUs have been mentioned in this error,
				// fall back to recording hosts of all attached IPUs
				if _, ok := eventRecord[gcipuinfo.KeyAttachedIPUHosts]; ok {
					hosts := eventRecord[gcipuinfo.KeyAttachedIPUHosts].([]interface{})
					for _, host := range hosts {
						hostsNamedInErrors[fmt.Sprint(host)] = true
					}
				}
			}
			severity := inventory.GetLastAppEventRecordSeverity(path);
			if (severity > gcipuinfo.EventSevWarning) {
				fmt.Println("Last event was an error.\n");
			}
		}
	}
	if len(hostsNamedInErrors) > 0 {
		fmt.Printf("== IPU-Machine hosts involved in errors, across all application event records:\n");
		for host, _ := range hostsNamedInErrors {
			fmt.Printf("  %s\n", host)
		}
	}
}
