//
// Copyright (c) 2021 Graphcore Ltd, All rights reserved.
//

// gcipuinfo examples:
// Loop forever, displaying a subset of attributes associated with
// devices that are currently in use.
// This demonstrates the GetDevices() function

package main

import (
	"os"
	"fmt"
	"time"
	"gcipuinfo"
)

func printAttribute(deviceMap map[string]interface{}, key string) {
	if deviceMap[key] != nil {
		fmt.Println("  ", key, " : ", deviceMap[key])
	}
}

func main() {
	discoveryMode := gcipuinfo.DiscoverActivePartitionIPUs
	if len(os.Args) > 1 {
		if os.Args[1] == "--all-partitions" {
			discoveryMode = gcipuinfo.DiscoverAllPartitionIPUs
		} else {
			fmt.Println("Error, unrecognised option.")
			fmt.Println("Specify --all-partitions to show IPUs in all partitions")
			os.Exit(1)
		}
	}

	inventory := gcipuinfo.NewGcipuinfo(discoveryMode)

	count := 0
	for {
		fmt.Println("*** Iteration ", count, " ***\n")
		count++

		inventory.UpdateData()
		deviceMaps := inventory.GetDevices()
		for _, attribs := range deviceMaps {
			deviceMap := attribs.(map[string]interface{})

			fmt.Println("Device ", deviceMap[gcipuinfo.DeviceId])

			if deviceMap[gcipuinfo.UserProcessId] != nil {
				printAttribute(deviceMap, gcipuinfo.UserProcessId)
				printAttribute(deviceMap, gcipuinfo.UserExecutable)
				printAttribute(deviceMap, gcipuinfo.UserName)
			} else {
				fmt.Println("  (device not in use by any known process)")
			}
			printAttribute(deviceMap, gcipuinfo.BoardIpuIndex)
			printAttribute(deviceMap, gcipuinfo.SerialNumber)
			printAttribute(deviceMap, gcipuinfo.ClockFrequency)
			printAttribute(deviceMap, gcipuinfo.TotalBoardPower)
			printAttribute(deviceMap, gcipuinfo.AverageBoardTemp)
			printAttribute(deviceMap, gcipuinfo.IpuUtilisation)
			printAttribute(deviceMap, gcipuinfo.MaxActiveCodeSize)
			printAttribute(deviceMap, gcipuinfo.MaxActiveDataSize)
			printAttribute(deviceMap, gcipuinfo.MaxActiveStackSize)
		}
		fmt.Println("")
		time.Sleep(1 * time.Second)
	}
}
