//
// Copyright (c) 2021 Graphcore Ltd, All rights reserved.
//

// gcipuinfo examples:
// Display health check results forever on all currently configured devices.

package main

import (
	"os"
	"fmt"
	"gcipuinfo"
	"encoding/json"
	"time"
)

func main() {
	discoveryMode := gcipuinfo.DiscoverActivePartitionIPUs
	if len(os.Args) > 1 {
		if os.Args[1] == "--all-partitions" {
			discoveryMode = gcipuinfo.DiscoverAllPartitionIPUs
		} else {
			fmt.Println("Error, unrecognised option.")
			fmt.Println("Specify --all-partitions to show IPUs in all partitions")
			os.Exit(1)
		}
	}

	inventory := gcipuinfo.NewGcipuinfo(discoveryMode)
	numIPUs := len(inventory.GetDevices())

	count := 0
	for {
		fmt.Println("*** Iteration ", count, " ***\n")
		fmt.Println("Checking ", numIPUs, " devices\n")
		count++

		var devicesHealth string
		devicesHealth = inventory.CheckHealthOfDevices(100, false)
		fmt.Println("Raw JSON:", devicesHealth)

		var result map[string]interface{}
		json.Unmarshal([]byte(devicesHealth), &result)
		if _, ok := result["hosts"]; ok {
			fmt.Println("Parsed:")
			hosts := result["hosts"].(map[string]interface{})
			for hostName, hostVal := range hosts {
				fmt.Println("  host: ", hostName)
				devices := hostVal.([]interface{})
				for _, deviceVal := range devices {
					device := deviceVal.(map[string]interface{})
					fmt.Println("    device id: ", device["id"], "partition: ", device["partition"], ", error: ", device["error"])
				}
			}
		} else if _, ok := result["error"]; ok {
			fmt.Println("Parsed:")
			fmt.Println("  error: ", result["error"], ", description: ", result["description"])
		} else {
			fmt.Println("No errors")
		}
		time.Sleep(time.Duration(10) * time.Millisecond)
	}
}
