#
# Copyright (c) 2021 Graphcore Ltd, All rights reserved.
#

# gcipuinfo examples: 
# Check each of the application event record paths specified
# as command line arguments.  If an entry is found, display it.
# Also collect a list of all IPU-Machine hosts named in
# at least one event.

import sys
import json
import gcipuinfo

if len(sys.argv) < 2:
  print("Error, requires at least one argument")
  sys.exit(1)

inventory = gcipuinfo.gcipuinfo()

hosts_named_in_errors = set()

for i in range(1,len(sys.argv)):
  path = sys.argv[i]
  print("== Checking application event record: " + path)
  event_record_json = inventory.getLastAppEventRecordAsJSON(inventory.EventSevNone, path)
  j = json.loads(event_record_json)
  if not j:
    print("No event record entry found.")
  else:
    print(event_record_json)

    # If the event has named specific IPUs
    # record their associated machine names
    found_specific_hosts = False
    if inventory.keySpecificIPUHosts in j:
      hosts = j[inventory.keySpecificIPUHosts]
      found_specific_hosts = len(hosts) > 0
      for host in hosts:
        hosts_named_in_errors.add(host)

    # if no specific IPUs have been mentioned in this error,
    # fall back to recording hosts of all attached IPUs
    if not found_specific_hosts and inventory.keyAttachedIPUHosts in j:
      hosts = j[inventory.keyAttachedIPUHosts]
      for host in hosts:
        hosts_named_in_errors.add(host)
    if (inventory.getLastAppEventRecordSeverity(path) > inventory.EventSevWarning):
      print("Last event was an error.")
  print("")

if len(hosts_named_in_errors) > 0:
  print("== IPU-Machine hosts involved in errors, across all application event records:")
  for host in hosts_named_in_errors:
    print("  " + host)
