#
# Copyright (c) 2021 Graphcore Ltd, All rights reserved.
#

# gcipuinfo examples:
# Loop forever, displaying a subset of attributes associated with
# devices that are currently in use.
# This demonstrates the getDevices() function

import time
import sys
import gcipuinfo

def print_attribute(map, key):
  if key in map:
    print("  " + key + " : " + map[key])


discovery_mode = gcipuinfo.DiscoverActivePartitionIPUs
if len(sys.argv) > 1:
  if sys.argv[1] == "--all-partitions":
    discovery_mode = gcipuinfo.DiscoverAllPartitionIPUs
  else:
    print("Error, unrecognised option.")
    print("Specify --all-partitions to show IPUs in all partitions")
    sys.exit(1)

inventory = gcipuinfo.gcipuinfo(discovery_mode)
apps = inventory.getNamedAttributeForAll(gcipuinfo.UserExecutable)

count = 0
while True:
  print("** Iteration " + str(count) + " ***")
  inventory.updateData()

  deviceMaps = inventory.getDevices()
  for deviceMap in deviceMaps:
    print("Device " + deviceMap[gcipuinfo.DeviceId])
    print_attribute(deviceMap, gcipuinfo.BoardIpuIndex)
    print_attribute(deviceMap, gcipuinfo.ClockFrequency)
    print_attribute(deviceMap, gcipuinfo.UserProcessId)
    print_attribute(deviceMap, gcipuinfo.UserExecutable)
    print_attribute(deviceMap, gcipuinfo.TotalBoardPower)
    print_attribute(deviceMap, gcipuinfo.AverageBoardTemp)
    print_attribute(deviceMap, gcipuinfo.AverageDieTemp)
    print_attribute(deviceMap, gcipuinfo.IpuUtilisation)
    print_attribute(deviceMap, gcipuinfo.MaxActiveCodeSize)
    print_attribute(deviceMap, gcipuinfo.MaxActiveDataSize)
    print_attribute(deviceMap, gcipuinfo.MaxActiveStackSize)
    print_attribute(deviceMap, gcipuinfo.HexoptActiveSize)
    print("")
  time.sleep(1)
  count = count+1
