#
# Copyright (c) 2021 Graphcore Ltd, All rights reserved.
#

# gcipuinfo examples:
# Display health check results forever on all currently configured devices.

import json
import time
import sys
import gcipuinfo

discovery_mode = gcipuinfo.DiscoverActivePartitionIPUs
if len(sys.argv) > 1:
  if sys.argv[1] == "--all-partitions":
    discovery_mode = gcipuinfo.DiscoverAllPartitionIPUs
  else:
    print("Error, unrecognised option.")
    print("Specify --all-partitions to show IPUs in all partitions")
    sys.exit(1)

inventory = gcipuinfo.gcipuinfo(discovery_mode)
num_ipus = len(inventory.getDevices())

count = 0
while True:
  print("** Iteration " + str(count) + " ***")
  print("Checking " + str(num_ipus) + " devices")
  devicesHealth = inventory.checkHealthOfDevices(100, False)
  print("Raw JSON: \n" + devicesHealth)
  j = json.loads(devicesHealth)
  if "hosts" in j:
    print("Parsed:")
    hosts = j["hosts"]
    for host_name in hosts:
      print("  host: " + host_name)
      for device in hosts[host_name]:
        print("    device id: " + device["id"] + ", partition: " + device["partition"] + ", error: " + device["error"])
  elif "error" in j:
    print("Parsed:")
    print("  error: " + j["error"] + ", description: " + j["description"])
  else:
    print("No errors")
  print("")
  count = count + 1
  time.sleep(0.01)
